# Copyright (c) 2010, 2011 Linaro Limited
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import re
from lava_test.core.installers import TestInstaller
from lava_test.core.parsers import TestParser
from lava_test.core.runners import TestRunner
from lava_test.core.tests import Test

RUNSTEPS = ["CAIRO_TEST_TARGET=egl,xlib CAIRO_TRACE_DIR=/usr/share/linaro-graphics-traces-cairo/ cairo-perf-trace -i3"]

class CairoTracesParser(TestParser):
    def parse_pathname(self, pathname, relative_pathname=None):
        filename = relative_pathname or pathname
        pat = re.compile("\[\s*\d+\]\s+(?P<backend>\S+)\s+(?P<test_name>\S+)\s+(?P<min>\d+\.\d+)\s+(?P<median>\d+\.\d+)")
        with open(pathname, 'rt') as stream:
            for lineno, line in enumerate(stream, 1):
                match = pat.search(line)
                if match:
                    d = match.groupdict()
                    for v in ("min", "median"):
                        r = {}
                        r['test_case_id'] = "%s.%s.%s" % (d["test_name"], d["backend"], v)
                        r['measurement'] = d[v]
                        r['log_filename'] = filename
                        r['log_lineno'] = lineno
                        self._results['test_results'].append(
                                self.analyze_test_result(r))

        return self.results

parse = CairoTracesParser(appendall={'units':'sec', 'result':'pass'})
inst = TestInstaller(deps=['linaro-graphics-traces-cairo', 'libcairo2', 'cairo-perf-utils'])
run = TestRunner(RUNSTEPS)

testobj = Test(test_id="linaro.gfx.cairo_traces", installer=inst,
               runner=run, parser=parse)
