# Copyright (c) 2010, 2011 Linaro Limited
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from lava_test.core.installers import TestInstaller
from lava_test.core.parsers import TestParser
from lava_test.core.runners import TestRunner
from lava_test.core.tests import Test
import pickle
from multi_test_parser import MultiTestParser
from timed_test_runner import TimedTestRunner

clutter_tests = [
    ("test-interactive", "test-cairo-flowers", 10),
    ("test-interactive", "test-actors", 10),
    ("test-interactive", "test-fbo", 10),
    ("test-interactive", "test-animator", 10),
    ("test-interactive", "test-cogl-shader-glsl", 10),
    ("test-random-text", "", 10),
]
cmd_fmt = "CLUTTER_SHOW_FPS=1 /usr/lib/clutter-1.0/tests/%s %s"

def create_test_cmds(tests):
    return [cmd_fmt % args[:2] for args in tests]

def create_test_runtimes(tests):
    return [args[2] for args in tests]

def create_test_info(tests):
    return ["%r" % pickle.dumps({'test_case_id':'%s.%s' % args[:2], 'units':'fps'}) for args in tests]


parse = MultiTestParser(pattern="\*\*\* FPS [^:]*: (?P<measurement>\d+) \*\*\*",
                        appendall={'result':'pass'})
inst = TestInstaller(deps=["clutter-1.0-tests"])
run = TimedTestRunner(create_test_cmds(clutter_tests),
                      create_test_runtimes(clutter_tests),
                      create_test_info(clutter_tests))

testobj = Test(test_id="linaro.gfx.clutter", installer=inst,
               runner=run, parser=parse)
