# Copyright (c) 2010, 2011 Linaro Limited
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import re
from lava_test.core.installers import TestInstaller
from lava_test.core.parsers import TestParser
from lava_test.core.runners import TestRunner
from lava_test.core.tests import Test

class GlcompbenchParser(TestParser):
    def parse_pathname(self, pathname, relative_pathname=None):
        pat_id = re.compile("^Running test: '(?P<test_case_id>.*)'")
        pat_fps = re.compile("^FPS: (?P<measurement>\d+)")
        pat_operation = re.compile("^Operation (?P<operation_id>.*) => Avg: (?P<avg>\d+\.\d+) Total: (?P<total>\d+\.\d+) Samples: (?P<samples>\d+)")
        cur_test = None
        sample_group = -1
        filename = relative_pathname or pathname
        with open(pathname, 'rt') as stream:
            for lineno, line in enumerate(stream, 1):
                match = pat_id.search(line)
                if match:
                    cur_test = match.groupdict()["test_case_id"]
                    sample_group = -1
                    continue

                match = pat_fps.search(line)
                if match:
                    d = match.groupdict()
                    sample_group = sample_group + 1
                    d["test_case_id"] = cur_test + "." + str(sample_group) + ".fps"
                    d["log_filename"] = filename
                    d["log_lineno"] = lineno
                    d["units"] = "fps"
                    self.results["test_results"].append(
                        self.analyze_test_result(d))
                    continue

                match = pat_operation.search(line)
                if match:
                    d = match.groupdict()
                    for val, units in (("avg", "ms"), ("total", "ms"), ("samples", "samples")):
                        r = {}
                        r["test_case_id"] = cur_test + "." + str(sample_group) + "." +\
                                            d["operation_id"] + "." + val
                        r["measurement"] = d[val]
                        r["log_filename"] = filename
                        r["log_lineno"] = lineno
                        r["units"] = units
                        self.results["test_results"].append(
                            self.analyze_test_result(r))

        return self.results

RUNSTEPS = ["gl-composite-benchmark -e glcompbench-egl-es2 -d 0.05"]

inst = TestInstaller(deps=["glcompbench-egl-es2"])
run = TestRunner(RUNSTEPS)
parse = GlcompbenchParser(appendall = {'result':'pass'})
testobj = Test(test_id="linaro.gfx.glcompbench", installer=inst,
               runner=run, parser=parse)
