# Copyright (c) 2010, 2011 Linaro Limited
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from lava_test.core.installers import TestInstaller
from lava_test.core.parsers import TestParser
from lava_test.core.runners import TestRunner
from lava_test.core.tests import Test
import re

class GlmemperfParser(TestParser):
    def parse_pathname(self, pathname, relative_pathname=None):
        pat_success = re.compile("^(?P<test_case_id>\w+):\W+(?P<measurement>\d+) fps")
        pat_failure = re.compile("^(?P<test_case_id>\w+):")
        with open(pathname, 'rt') as stream:
            for lineno, line in enumerate(stream, 1):
                match = pat_success.search(line)
                if match:
                    data = match.groupdict()
                    data["log_filename"] = relative_pathname or pathname
                    data["log_lineno"] = lineno
                    data["units"] = "fps"
                    data["result"] = "pass"
                    self._results['test_results'].append(
                         self.analyze_test_result(data))
                    continue

                match = pat_failure.search(line)
                if match:
                    data = match.groupdict()
                    data["log_filename"] = relative_pathname or pathname
                    data["log_lineno"] = lineno
                    data["result"] = "fail"
                    self._results['test_results'].append(
                         self.analyze_test_result(data))

        return self.results

RUNSTEPS = ["glmemperf"]

inst = TestInstaller(deps=["glmemperf"])
run = TestRunner(RUNSTEPS)
parse = GlmemperfParser()

testobj = Test(test_id="linaro.gfx.glmemperf", installer=inst,
               runner=run, parser=parse)
