# Copyright (c) 2010, 2011 Linaro Limited
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import re
from lava_test.core.parsers import TestParser
import pickle

class MultiTestParser(TestParser):
    """Multiple test result parser

    Parses a series of results from multiple tests. The test results
    are separated using a '$Start LavaTest$ INFO' line, where INFO
    is a pickled representation of a python dictionary that is used
    as the base for the test results.
    """
    def parse_pathname(self, pathname, relative_pathname=None):
        info = {}
        pat_start = re.compile("^\$Start LavaTest\$ (?P<info>.*)")
        with open(pathname, 'rt') as stream:
            for lineno, line in enumerate(stream, 1):
                # Search for start-of-test tag
                match = re.search(pat_start, line)
                if match:
                    d = match.groupdict()
                    info = pickle.loads(d["info"].decode("string-escape")[1:])
                    continue

                match = re.search(self.pattern, line)
                if not match:
                    continue
                data = info.copy()
                data.update(match.groupdict())
                data["log_filename"] = relative_pathname or pathname
                data["log_lineno"] = lineno
                self._results['test_results'].append(
                        self.analyze_test_result(data))

        return self.results
