# Copyright (c) 2010, 2011 Linaro Limited
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import re
from lava_test.core.installers import TestInstaller
from lava_test.core.parsers import TestParser
from lava_test.core.runners import TestRunner
from lava_test.core.tests import Test

class RenderBenchParser(TestParser):
    def parse_pathname(self, pathname, relative_pathname=None):
        pat_id = re.compile("^Test: (?P<test_case_id>.*)")
        pat_result = re.compile("^Time: (?P<measurement>\d+\.\d+)")
        cur_test = None
        filename = relative_pathname or pathname
        with open(pathname, 'rt') as stream:
            for lineno, line in enumerate(stream, 1):
                match = pat_id.search(line)
                if match:
                    cur_test = match.groupdict()['test_case_id'].replace(' ', '_')
                    continue
                match = pat_result.search(line)
                if match:
                    d = match.groupdict()
                    d['test_case_id'] = cur_test
                    d['log_filename'] = filename
                    d['log_lineno'] = lineno
                    self.results["test_results"].append(
                        self.analyze_test_result(d))

        return self.results

RUNSTEPS = ["render_bench"]

inst = TestInstaller(deps=["render-bench"])
run = TestRunner(RUNSTEPS)
parse = RenderBenchParser(appendall={'units':'seconds', 'result':'pass'})

testobj = Test(test_id="linaro.gfx.render_bench", installer=inst,
               runner=run, parser=parse)
