# Copyright (c) 2010, 2011 Linaro Limited
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from lava_test.api.delegates import ITestRunner
import datetime
import pty
import time
import os
import subprocess
import signal
import sys


class TimedTestRunner(ITestRunner):
    def __init__(self, steps=None, runtime=None, info=None, default_options=None):
        self.steps = steps or []
        self.runtime = runtime or []
        self.info = info or []
        self.default_options = default_options

    def __repr__(self):
        return "<%s steps=%r runtime=%r>" % (self.__class__.__name__, self.steps, self.runtime)

    def _run_lava_test_steps(self, artifacts, observer, test_options=None):
        stdout = open(artifacts.stdout_pathname, 'at')
        run_failed = False
        try:
            for (cmd, runtime, info) in zip(self.steps, self.runtime, self.info):
                # should override the test options in the step ?
                if cmd.find("$(OPTIONS)") > 0:
                    # check if test options is provided or use default options
                    if not test_options and self.default_options == None:
                        raise RuntimeError("Test options is missing. No default value is provided.")
                    if not test_options:
                        test_options = self.default_options
                    cmd = cmd.replace("$(OPTIONS)",test_options)

                if observer: observer.about_to_run_shell_command(cmd)

                # Run the benchmark in a new process with new pty.
                # We need a pty for two reasons:
                # 1. To make sure the output is line-buffered and therefore
                #    immediately available. Otherwise, when killing the
                #    process we may not get the whole benchmark output (or
                #    none at all) because the buffers are not flushed.
                # 2. To ensure that we properly kill the benchmark process
                #    by killing the controlling terminal process. Otherwise,
                #    (eg if we just forked) we could kill the parent process
                #    but the child process would remain as a zombie.
                (pid, ptyfd) = pty.fork()
                if pid == 0:
                    try:
                        print >>stdout, "$Start LavaTest$ %s" % info
                        subprocess.call(cmd, shell=True)
                    except:
                        pass
                    sys.exit()

                # Kill the benchmark pty (and therefore the benchmark process)
                # after the timeout has expired
                time.sleep(runtime)
                os.kill(pid, signal.SIGINT)
                # Force a return code of 0
                returncode = 0

                # Make the benchmark stdout (in ptyfd) available to lava-test
                # by saving it in the log file.
                out = os.read(ptyfd, 1024)
                while out != "":
                    stdout.write(out)
                    out = ""
                    try:
                        out = os.read(ptyfd, 1024)
                    except:
                        pass

                print >>stdout, "$End LavaTest$ %s" % info

                if observer: observer.did_run_shell_command(cmd, returncode)
                if (returncode != 0): run_failed = True
        finally:
            stdout.close()
        return run_failed

    def run(self, artifacts, observer=None, test_options = None):
        self.starttime = datetime.datetime.utcnow()
        run_failed = self._run_lava_test_steps(artifacts, observer, test_options)
        self.endtime = datetime.datetime.utcnow()
        return run_failed
